@@ -36,7 +36,6 @@ if [ "$DIB_INSTALLTYPE_puppet_modules" = "source" ]; then
     puppet-kibana3 \
     puppet-memcached \
     puppet-mistral \
-    puppetlabs-mongodb \
     puppetlabs-mysql \
     puppet-neutron \
     puppet-octavia \
@@ -52,8 +51,6 @@ if [ "$DIB_INSTALLTYPE_puppet_modules" = "source" ]; then
     puppet-redis \
     puppetlabs-rsync \
     puppet-sahara \
-    puppet-tacker \
-    puppet-trove \
     puppet-ssh \
     puppet-staging \
     puppetlabs-stdlib \
@@ -84,7 +81,7 @@ if [ "$DIB_INSTALLTYPE_puppet_modules" = "source" ]; then
     puppet-etcd \
     puppet-zaqar \
     puppet-veritas_hyperscale \
-    puppet-ptp; do
+    puppet-ptp ; do
     export DIB_INSTALLTYPE_${module_name//\-/_}='source'
   done
 fi
